==> huaweicloudsdkprojectman-3.0.13b0-py3-none-any.whl: huaweicloudsdkprojectman/v4/model/show_cur_user_info_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ShowCurUserInfoResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'domain_id': 'str',
        'domain_name': 'str',
        'user_num_id': 'int',
        'user_id': 'str',
        'user_name': 'str',
        'nick_name': 'str',
        'created_time': 'str',
        'updated_time': 'str',
        'gender': 'str',
        'user_type': 'str'
    }

    attribute_map = {
        'domain_id': 'domain_id',
        'domain_name': 'domain_name',
        'user_num_id': 'user_num_id',
        'user_id': 'user_id',
        'user_name': 'user_name',
        'nick_name': 'nick_name',
        'created_time': 'created_time',
        'updated_time': 'updated_time',
        'gender': 'gender',
        'user_type': 'user_type'
    }

    def __init__(self, domain_id=None, domain_name=None, user_num_id=None, user_id=None, user_name=None, nick_name=None, created_time=None, updated_time=None, gender=None, user_type=None):
        """ShowCurUserInfoResponse - a model defined in huaweicloud sdk"""
        
        super().__init__()

        self._domain_id = None
        self._domain_name = None
        self._user_num_id = None
        self._user_id = None
        self._user_name = None
        self._nick_name = None
        self._created_time = None
        self._updated_time = None
        self._gender = None
        self._user_type = None
        self.discriminator = None

        if domain_id is not None:
            self.domain_id = domain_id
        if domain_name is not None:
            self.domain_name = domain_name
        if user_num_id is not None:
            self.user_num_id = user_num_id
        if user_id is not None:
            self.user_id = user_id
        if user_name is not None:
            self.user_name = user_name
        if nick_name is not None:
            self.nick_name = nick_name
        if created_time is not None:
            self.created_time = created_time
        if updated_time is not None:
            self.updated_time = updated_time
        if gender is not None:
            self.gender = gender
        if user_type is not None:
            self.user_type = user_type

    @property
    def domain_id(self):
        """Gets the domain_id of this ShowCurUserInfoResponse.

        租户id

        :return: The domain_id of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this ShowCurUserInfoResponse.

        租户id

        :param domain_id: The domain_id of this ShowCurUserInfoResponse.
        :type: str
        """
        self._domain_id = domain_id

    @property
    def domain_name(self):
        """Gets the domain_name of this ShowCurUserInfoResponse.

        租户名

        :return: The domain_name of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """Sets the domain_name of this ShowCurUserInfoResponse.

        租户名

        :param domain_name: The domain_name of this ShowCurUserInfoResponse.
        :type: str
        """
        self._domain_name = domain_name

    @property
    def user_num_id(self):
        """Gets the user_num_id of this ShowCurUserInfoResponse.

        用户数字id

        :return: The user_num_id of this ShowCurUserInfoResponse.
        :rtype: int
        """
        return self._user_num_id

    @user_num_id.setter
    def user_num_id(self, user_num_id):
        """Sets the user_num_id of this ShowCurUserInfoResponse.

        用户数字id

        :param user_num_id: The user_num_id of this ShowCurUserInfoResponse.
        :type: int
        """
        self._user_num_id = user_num_id

    @property
    def user_id(self):
        """Gets the user_id of this ShowCurUserInfoResponse.

        用户id

        :return: The user_id of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ShowCurUserInfoResponse.

        用户id

        :param user_id: The user_id of this ShowCurUserInfoResponse.
        :type: str
        """
        self._user_id = user_id

    @property
    def user_name(self):
        """Gets the user_name of this ShowCurUserInfoResponse.

        用户名

        :return: The user_name of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this ShowCurUserInfoResponse.

        用户名

        :param user_name: The user_name of this ShowCurUserInfoResponse.
        :type: str
        """
        self._user_name = user_name

    @property
    def nick_name(self):
        """Gets the nick_name of this ShowCurUserInfoResponse.

        用户昵称

        :return: The nick_name of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._nick_name

    @nick_name.setter
    def nick_name(self, nick_name):
        """Sets the nick_name of this ShowCurUserInfoResponse.

        用户昵称

        :param nick_name: The nick_name of this ShowCurUserInfoResponse.
        :type: str
        """
        self._nick_name = nick_name

    @property
    def created_time(self):
        """Gets the created_time of this ShowCurUserInfoResponse.

        创建时间

        :return: The created_time of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this ShowCurUserInfoResponse.

        创建时间

        :param created_time: The created_time of this ShowCurUserInfoResponse.
        :type: str
        """
        self._created_time = created_time

    @property
    def updated_time(self):
        """Gets the updated_time of this ShowCurUserInfoResponse.

        更新时间

        :return: The updated_time of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._updated_time

    @updated_time.setter
    def updated_time(self, updated_time):
        """Sets the updated_time of this ShowCurUserInfoResponse.

        更新时间

        :param updated_time: The updated_time of this ShowCurUserInfoResponse.
        :type: str
        """
        self._updated_time = updated_time

    @property
    def gender(self):
        """Gets the gender of this ShowCurUserInfoResponse.

        性别

        :return: The gender of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """Sets the gender of this ShowCurUserInfoResponse.

        性别

        :param gender: The gender of this ShowCurUserInfoResponse.
        :type: str
        """
        self._gender = gender

    @property
    def user_type(self):
        """Gets the user_type of this ShowCurUserInfoResponse.

        用户类型 User 云用户 Federation 联邦账号

        :return: The user_type of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this ShowCurUserInfoResponse.

        用户类型 User 云用户 Federation 联邦账号

        :param user_type: The user_type of this ShowCurUserInfoResponse.
        :type: str
        """
        self._user_type = user_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowCurUserInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkprojectman-3.0.41rc0-py3-none-any.whl: huaweicloudsdkprojectman/v4/model/show_cur_user_info_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class ShowCurUserInfoResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'domain_id': 'str',
        'domain_name': 'str',
        'user_num_id': 'int',
        'user_id': 'str',
        'user_name': 'str',
        'nick_name': 'str',
        'created_time': 'int',
        'updated_time': 'int',
        'gender': 'str',
        'user_type': 'str'
    }

    attribute_map = {
        'domain_id': 'domain_id',
        'domain_name': 'domain_name',
        'user_num_id': 'user_num_id',
        'user_id': 'user_id',
        'user_name': 'user_name',
        'nick_name': 'nick_name',
        'created_time': 'created_time',
        'updated_time': 'updated_time',
        'gender': 'gender',
        'user_type': 'user_type'
    }

    def __init__(self, domain_id=None, domain_name=None, user_num_id=None, user_id=None, user_name=None, nick_name=None, created_time=None, updated_time=None, gender=None, user_type=None):
        """ShowCurUserInfoResponse - a model defined in huaweicloud sdk"""
        
        super().__init__()

        self._domain_id = None
        self._domain_name = None
        self._user_num_id = None
        self._user_id = None
        self._user_name = None
        self._nick_name = None
        self._created_time = None
        self._updated_time = None
        self._gender = None
        self._user_type = None
        self.discriminator = None

        if domain_id is not None:
            self.domain_id = domain_id
        if domain_name is not None:
            self.domain_name = domain_name
        if user_num_id is not None:
            self.user_num_id = user_num_id
        if user_id is not None:
            self.user_id = user_id
        if user_name is not None:
            self.user_name = user_name
        if nick_name is not None:
            self.nick_name = nick_name
        if created_time is not None:
            self.created_time = created_time
        if updated_time is not None:
            self.updated_time = updated_time
        if gender is not None:
            self.gender = gender
        if user_type is not None:
            self.user_type = user_type

    @property
    def domain_id(self):
        """Gets the domain_id of this ShowCurUserInfoResponse.

        租户id

        :return: The domain_id of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._domain_id

    @domain_id.setter
    def domain_id(self, domain_id):
        """Sets the domain_id of this ShowCurUserInfoResponse.

        租户id

        :param domain_id: The domain_id of this ShowCurUserInfoResponse.
        :type: str
        """
        self._domain_id = domain_id

    @property
    def domain_name(self):
        """Gets the domain_name of this ShowCurUserInfoResponse.

        租户名

        :return: The domain_name of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """Sets the domain_name of this ShowCurUserInfoResponse.

        租户名

        :param domain_name: The domain_name of this ShowCurUserInfoResponse.
        :type: str
        """
        self._domain_name = domain_name

    @property
    def user_num_id(self):
        """Gets the user_num_id of this ShowCurUserInfoResponse.

        用户数字id

        :return: The user_num_id of this ShowCurUserInfoResponse.
        :rtype: int
        """
        return self._user_num_id

    @user_num_id.setter
    def user_num_id(self, user_num_id):
        """Sets the user_num_id of this ShowCurUserInfoResponse.

        用户数字id

        :param user_num_id: The user_num_id of this ShowCurUserInfoResponse.
        :type: int
        """
        self._user_num_id = user_num_id

    @property
    def user_id(self):
        """Gets the user_id of this ShowCurUserInfoResponse.

        用户id

        :return: The user_id of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ShowCurUserInfoResponse.

        用户id

        :param user_id: The user_id of this ShowCurUserInfoResponse.
        :type: str
        """
        self._user_id = user_id

    @property
    def user_name(self):
        """Gets the user_name of this ShowCurUserInfoResponse.

        用户名

        :return: The user_name of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this ShowCurUserInfoResponse.

        用户名

        :param user_name: The user_name of this ShowCurUserInfoResponse.
        :type: str
        """
        self._user_name = user_name

    @property
    def nick_name(self):
        """Gets the nick_name of this ShowCurUserInfoResponse.

        用户昵称

        :return: The nick_name of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._nick_name

    @nick_name.setter
    def nick_name(self, nick_name):
        """Sets the nick_name of this ShowCurUserInfoResponse.

        用户昵称

        :param nick_name: The nick_name of this ShowCurUserInfoResponse.
        :type: str
        """
        self._nick_name = nick_name

    @property
    def created_time(self):
        """Gets the created_time of this ShowCurUserInfoResponse.

        创建时间

        :return: The created_time of this ShowCurUserInfoResponse.
        :rtype: int
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """Sets the created_time of this ShowCurUserInfoResponse.

        创建时间

        :param created_time: The created_time of this ShowCurUserInfoResponse.
        :type: int
        """
        self._created_time = created_time

    @property
    def updated_time(self):
        """Gets the updated_time of this ShowCurUserInfoResponse.

        更新时间

        :return: The updated_time of this ShowCurUserInfoResponse.
        :rtype: int
        """
        return self._updated_time

    @updated_time.setter
    def updated_time(self, updated_time):
        """Sets the updated_time of this ShowCurUserInfoResponse.

        更新时间

        :param updated_time: The updated_time of this ShowCurUserInfoResponse.
        :type: int
        """
        self._updated_time = updated_time

    @property
    def gender(self):
        """Gets the gender of this ShowCurUserInfoResponse.

        性别

        :return: The gender of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """Sets the gender of this ShowCurUserInfoResponse.

        性别

        :param gender: The gender of this ShowCurUserInfoResponse.
        :type: str
        """
        self._gender = gender

    @property
    def user_type(self):
        """Gets the user_type of this ShowCurUserInfoResponse.

        用户类型, User 云用户, Federation 联邦账号,

        :return: The user_type of this ShowCurUserInfoResponse.
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this ShowCurUserInfoResponse.

        用户类型, User 云用户, Federation 联邦账号,

        :param user_type: The user_type of this ShowCurUserInfoResponse.
        :type: str
        """
        self._user_type = user_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowCurUserInfoResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
